GrafoNode class

Constructors

GrafoNode({int id = 0, String? name, List<GrafoNode>? children, bool selected = false, Offset position = const Offset(0, 0), Size size = const Size(100, 100)})

Properties

centerPosition Offset
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
final
name String?
final
position Offset
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pair
size Size
final

Methods

copyWith({int? id, Offset? position, String? name, Size? size, bool? selected}) GrafoNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited